==> arquillian-container-test-impl-base-1.1.10.Final-sources.jar: org/jboss/arquillian/container/test/impl/client/container/command/StopContainerCommand.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.test.impl.client.container.command;

import org.jboss.arquillian.container.test.impl.client.deployment.command.AbstractCommand;


/**
 * StartContainerCommand
 *
 * @author <a href="mailto:mgencur@redhat.com">Martin Gencur</a>
 * @version $Revision: $
 */
public class StopContainerCommand extends AbstractCommand<String>
{
   private static final long serialVersionUID = 1L;

   private String containerQualifier;
   
   public StopContainerCommand(String containerQualifier)
   {
      this.containerQualifier = containerQualifier;
   }
   
   /**
    * @return the containerQualifier
    */
   public String getContainerQualifier()
   {
      return containerQualifier;
   }
}

==> arquillian-container-test-impl-base-1.6.0.Final-sources.jar: org/jboss/arquillian/container/test/impl/client/container/command/StopContainerCommand.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.test.impl.client.container.command;

import org.jboss.arquillian.container.test.impl.client.deployment.command.AbstractCommand;

/**
 * StartContainerCommand
 *
 * @author <a href="mailto:mgencur@redhat.com">Martin Gencur</a>
 * @version $Revision: $
 */
public class StopContainerCommand extends AbstractCommand<String> {
    private static final long serialVersionUID = 1L;

    private String containerQualifier;

    public StopContainerCommand(String containerQualifier) {
        this.containerQualifier = containerQualifier;
    }

    /**
     * @return the containerQualifier
     */
    public String getContainerQualifier() {
        return containerQualifier;
    }
}
